MirrorHeader class
u32 header slots, mirroring MINIAV_MIRROR_HEADER_U32 in the C producer.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- capacityFrames → const int
- channels → const int
- overrunFrames → const int
- readCursor → const int
- sampleRate → const int
- slots → const int
- writeCursor → const int